<?php

namespace App\Controllers;

use App\Models\FlightModel;
use App\Models\CityModel;
use App\Models\HotelModel;
use App\Models\RoomModel;
use App\Models\RoomTypeModel;
use App\Models\RequestModel;
use App\Models\RequestHotelModel;
use App\Models\PassengerModel;
use App\Models\UserModel;
use App\Models\MessageModel;
use App\Models\ActivityLogModel;
use App\Models\RtqModel;
use App\Libraries\PdfGenerator;


class Request extends BaseController
{
    protected $requestModel;
    protected $userModel;
  	protected $messageModel;
    protected $activityLogModel;

    public function __construct()
    {
        $this->requestModel = new RequestModel();
        $this->userModel = new UserModel();
      	$this->messageModel = new MessageModel();
        $this->activityLogModel = new ActivityLogModel();
    }

    public function new()
    {
        $flightModel = new FlightModel();
        $cityModel = new CityModel();
      	$hotelModel = new HotelModel();

        $data = [
            'flights' => $flightModel->findAll(),
            'cities' => $cityModel->findAll(),
          	'hotels' => $hotelModel->where('is_active', 1)->findAll(), // Only fetch active hotels
        ];

        return view('request/new', $data);
    }

    public function getHotels()
	{
    $cityId = $this->request->getGet('city_id');
    $hotelModel = new \App\Models\HotelModel();
    $hotels = $hotelModel->where('city_id', $cityId)->findAll();
    
    return $this->response->setJSON($hotels);
	}

    public function getRooms()
    {
        $hotelId = $this->request->getGet('hotel_id');
        $roomModel = new RoomModel();
        $roomTypeModel = new RoomTypeModel();
        
        $rooms = $roomModel->where('hotel_id', $hotelId)->findAll();
        $roomsWithTypes = [];
        foreach ($rooms as $room) {
            $roomType = $roomTypeModel->find($room['room_type_id']);
            if ($roomType) {
                $roomsWithTypes[] = [
                    'id' => $room['id'],
                    'room_type' => $roomType['name']
                ];
            }
        }
        return $this->response->setJSON($roomsWithTypes);
    }


    public function submit()
    {
      
    $requestModel = new RequestModel();
    $requestHotelModel = new RequestHotelModel();
    $passengerModel = new PassengerModel();

    // Generate unique ID
    $uniqueId = 'BRZ' . str_pad($requestModel->countAllResults() + 1, 7, '0', STR_PAD_LEFT);

    // Create main request
    $requestData = [
        'unique_id' => $uniqueId,
        'user_id' => session()->get('user_id'),
        'arrival_flight_id' => $this->request->getPost('arrival_flight'),
        'departure_flight_id' => $this->request->getPost('departure_flight'),
        'status' => 'new',
        'created_at' => date('Y-m-d H:i:s'),  // Explicitly set the creation date
        'updated_at' => date('Y-m-d H:i:s')   // Explicitly set the update date
    ];
    $requestId = $requestModel->insert($requestData);

        // Process hotel selections
        $hotels = $this->request->getPost('hotel');
        $rooms = $this->request->getPost('room');
        $nights = $this->request->getPost('nights');
        $roomQuantities = $this->request->getPost('room_quantity');
        $checkIns = $this->request->getPost('check_in');
        $checkOuts = $this->request->getPost('check_out');
        $extraBeds = $this->request->getPost('extra_bed');
        $cwbs = $this->request->getPost('cwb');
        $cnbs = $this->request->getPost('cnb');
        $notes = $this->request->getPost('notes');
      
      	//log_message('debug', 'Hotels: ' . print_r($hotels, true));
    	//log_message('debug', 'Rooms: ' . print_r($rooms, true));

        if (is_array($hotels)) {
        foreach ($hotels as $index => $hotelId) {
            if (!empty($hotelId) && !empty($rooms[$index])) {
                $requestHotelModel->insert([
                    'request_id' => $requestId,
                    'hotel_id' => $hotelId,
                    'room_id' => $rooms[$index],
                    'nights' => $nights[$index],
                    'room_quantity' => $roomQuantities[$index],
                    'check_in' => $checkIns[$index],
                    'check_out' => $checkOuts[$index],
                    'extra_bed' => isset($extraBeds[$index]) ? 1 : 0,
                    'cwb' => isset($cwbs[$index]) ? 1 : 0,
                    'cnb' => isset($cnbs[$index]) ? 1 : 0,
                    'notes' => $notes[$index]
                ]);
        }
        }
        }

        // Process passengers
        $surnames = $this->request->getPost('surname');
        $names = $this->request->getPost('name');
        $genders = $this->request->getPost('gender');
        $isAdults = $this->request->getPost('is_adult');
        $isInfants = $this->request->getPost('is_infant');

        foreach ($surnames as $index => $surname) {
            $passengerModel->insert([
                'request_id' => $requestId,
                'surname' => $surname,
                'name' => $names[$index],
                'gender' => $genders[$index],
                'is_adult' => isset($isAdults[$index]) ? 1 : 0,
                'is_infant' => isset($isInfants[$index]) ? 1 : 0
            ]);
        }

        return redirect()->to(base_url('requests'))->with('message', 'Request submitted successfully. Request ID: ' . $uniqueId);
      	// Debugging: Log all POST data
    	//log_message('debug', 'Form submission data: ' . print_r($this->request->getPost(), true));

    }

    public function index()
    {
        $userId = session()->get('user_id');
        $userRole = session()->get('role');
        
        if ($userRole == 'admin' || $userRole == 'agent') {
            $data['requests'] = $this->requestModel->getAllRequests();
        } else {
            $data['requests'] = $this->requestModel->getUserRequests($userId);
        }
        
        return view('request/index', $data);
    }

    public function view($id)
    {
        $data['request'] = $this->requestModel->getRequestDetails($id);
        log_message('debug', 'Request details: ' . print_r($data['request'], true));
        
        return view('request/view', $data);
    }
  	
  	public function reply($id)
	{
    try {
        $message = $this->request->getPost('message');
        $attachment = $this->request->getFile('attachment');

        if (empty($message)) {
            return $this->response->setJSON(['success' => false, 'error' => 'Message cannot be empty']);
        }

        $messageData = [
            'request_id' => $id,
            'user_id' => session()->get('user_id'),
            'message' => $message,
            'created_at' => date('Y-m-d H:i:s')
        ];

        if ($attachment && $attachment->isValid() && !$attachment->hasMoved()) {
            $newName = $attachment->getRandomName();
            $attachment->move(FCPATH . 'uploads', $newName);
            $messageData['attachment'] = $newName;
        }

        $inserted = $this->messageModel->insert($messageData);
        if (!$inserted) {
            log_message('error', 'Failed to insert message: ' . print_r($this->messageModel->errors(), true));
            return $this->response->setStatusCode(500)->setJSON(['success' => false, 'error' => 'Failed to save message']);
        }

        $this->activityLogModel->log($id, session()->get('user_id'), 'replied to the request');

        return $this->response->setJSON(['success' => true]);
    } catch (\Exception $e) {
        log_message('error', 'Error in reply method: ' . $e->getMessage() . "\n" . $e->getTraceAsString());
        return $this->response->setStatusCode(500)->setJSON(['success' => false, 'error' => 'An unexpected error occurred']);
    }
	}
  	
  	public function messages($id)
	{
    $messages = $this->messageModel->getRequestMessages($id);
    return $this->response->setJSON(['success' => true, 'messages' => view('request/messages', ['messages' => $messages])]);
	}

    public function activity($id)
	{
    try {
        $activities = $this->activityLogModel->getRequestActivities($id);
        return $this->response->setJSON([
            'success' => true, 
            'activities' => view('request/activity', ['activities' => $activities])
        ]);
    } catch (\Exception $e) {
        log_message('error', 'Error in activity method: ' . $e->getMessage() . "\n" . $e->getTraceAsString());
        return $this->response->setStatusCode(500)->setJSON(['success' => false, 'error' => 'An unexpected error occurred']);
    }
	}

    public function updateStatus($id)
    {
        $status = $this->request->getPost('status');
        $this->requestModel->update($id, ['status' => $status]);
        $this->activityLogModel->log($id, session()->get('user_id'), "updated status to '$status'");

        if ($status == 'waiting for confirmation') {
            $this->createRtq($id);
        }

        return $this->response->setJSON(['success' => true]);
    }

    private function createRtq($requestId)
    {
        // Create the RtqModel instance here
        $rtqModel = new RtqModel();

        $rtqData = [
            'request_id' => $requestId,
            'status' => 'pending',
            'notes' => 'Forwarded from request'
        ];
        $rtqModel->insert($rtqData);
    }

   public function edit($id)
	{
    if (session()->get('role') != 'admin') {
        return redirect()->to('/requests')->with('error', 'You do not have permission to edit requests.');
    }

    $requestModel = new \App\Models\RequestModel();
    $flightModel = new \App\Models\FlightModel();
    $hotelModel = new \App\Models\HotelModel();
    $roomModel = new \App\Models\RoomModel();

    $data['request'] = $requestModel->getRequestDetails($id);
    if (empty($data['request'])) {
        return redirect()->to('/requests')->with('error', 'Request not found.');
    }

    $data['flights'] = $flightModel->findAll();
    $data['hotels'] = $hotelModel->findAll();
    
    // Fetch rooms with their types
    $data['rooms'] = $roomModel->select('rooms.*, room_types.name as room_type')
                               ->join('room_types', 'room_types.id = rooms.room_type_id')
                               ->findAll();

    // Debug information
    log_message('debug', 'Request data: ' . print_r($data['request'], true));
    log_message('debug', 'Rooms data: ' . print_r($data['rooms'], true));

    return view('request/edit', $data);
	}

    public function delete($id)
	{
    if (session()->get('role') != 'admin') {
        return redirect()->to('/requests')->with('error', 'You do not have permission to delete requests.');
    }

    if ($this->requestModel->delete($id)) {
        return redirect()->to('/requests')->with('message', 'Request deleted successfully.');
    } else {
        return redirect()->to('/requests')->with('error', 'Failed to delete request.');
    }
	}
  
  	public function update($id)
{
    if (session()->get('role') != 'admin') {
        return redirect()->to('/requests')->with('error', 'You do not have permission to update requests.');
    }

    $requestModel = new \App\Models\RequestModel();
    $requestHotelModel = new \App\Models\RequestHotelModel();
    $passengerModel = new \App\Models\PassengerModel();

    // Fetch the current request data
    $currentRequest = $requestModel->find($id);
    if (!$currentRequest) {
        return redirect()->to('/requests')->with('error', 'Request not found.');
    }

    // Update main request data
    $requestData = [
        'status' => $this->request->getPost('status'),
        'arrival_flight_id' => $this->request->getPost('arrival_flight'),
        'departure_flight_id' => $this->request->getPost('departure_flight'),
    ];
    $requestModel->update($id, $requestData);

    // Update hotel information
    $hotels = $this->request->getPost('hotels');
    if (is_array($hotels)) {
        foreach ($hotels as $hotel) {
            if (isset($hotel['id'])) {
                $requestHotelModel->update($hotel['id'], [
                    'hotel_id' => $hotel['hotel_id'],
                    'room_id' => $hotel['room_id'],
                    'check_in' => $hotel['check_in'],
                    'check_out' => $hotel['check_out'],
                    'nights' => $hotel['nights'],
                    'room_quantity' => $hotel['room_quantity'],
                    'extra_bed' => isset($hotel['extra_bed']) ? 1 : 0,
                    'cwb' => isset($hotel['cwb']) ? 1 : 0,
                    'cnb' => isset($hotel['cnb']) ? 1 : 0,
                    'notes' => $hotel['notes'] ?? '',
                ]);
            }
        }
    }

    // Update passenger information
    $passengers = $this->request->getPost('passengers');
    if (is_array($passengers)) {
        foreach ($passengers as $passenger) {
            if (isset($passenger['id'])) {
                $passengerModel->update($passenger['id'], [
                    'name' => $passenger['name'],
                    'surname' => $passenger['surname'],
                    'gender' => $passenger['gender'],
                    'is_adult' => isset($passenger['is_adult']) ? 1 : 0,
                    'is_infant' => isset($passenger['is_infant']) ? 1 : 0,
                ]);
            }
        }
    }

    // Log the activity
    $activityLogModel = new \App\Models\ActivityLogModel();
    $activityLogModel->log($id, session()->get('user_id'), 'updated the request');

    return redirect()->to("/requests/view/$id")->with('message', 'Request updated successfully.');
}

    public function search()
    {
        $searchTerm = $this->request->getGet('search');
        $data['requests'] = $this->requestModel->searchRequests($searchTerm);
        return view('request/index', $data);
    }
  
  	public function searchFlights()
    {
        $term = $this->request->getGet('term');
        $flightModel = new FlightModel();
        $flights = $flightModel->like('flight_number', $term)
                               ->orLike('departure_city', $term)
                               ->orLike('arrival_city', $term)
                               ->findAll(10);  // Limit to 10 results
        return $this->response->setJSON($flights);
    }
  
  	public function searchHotels()
	{
    $term = $this->request->getGet('term');
    $cityId = $this->request->getGet('city_id');
    $hotelModel = new HotelModel();
    $query = $hotelModel->like('name', $term)->where('is_active', 1);
    if ($cityId) {
        $query->where('city_id', $cityId);
    }
    $hotels = $query->findAll(10);  // Limit to 10 results
    return $this->response->setJSON($hotels);
	}
  
  
  
  
  	public function voucherGenerator()
    {
        $flightModel = new \App\Models\FlightModel();
        $cityModel = new \App\Models\CityModel();
        $hotelModel = new \App\Models\HotelModel();
        $roomTypeModel = new \App\Models\RoomTypeModel();

        $data = [
            'flights' => $flightModel->findAll(),
            'cities' => $cityModel->findAll(),
            'hotels' => $hotelModel->where('is_active', 1)->findAll(),
            'roomTypes' => $roomTypeModel->findAll(),
        ];

        return view('request/voucher_generator', $data);
    }

    public function generateVoucher()
    {
        $pdfGenerator = new PdfGenerator();

        $flightModel = new \App\Models\FlightModel();
        $hotelModel = new \App\Models\HotelModel();
        $roomTypeModel = new \App\Models\RoomTypeModel();

        $request = [
            'unique_id' => $this->request->getPost('request_id'),
            'created_at' => date('Y-m-d H:i:s'),
            'passengers' => [],
        ];

        // Process flight information
        $arrivalFlightId = $this->request->getPost('arrival_flight');
        $departureFlightId = $this->request->getPost('departure_flight');
        $request['arrival_flight'] = $flightModel->find($arrivalFlightId) ?? [];
        $request['departure_flight'] = $flightModel->find($departureFlightId) ?? [];

        // Process passenger information
        $surnames = $this->request->getPost('surname') ?? [];
        $names = $this->request->getPost('name') ?? [];
        $genders = $this->request->getPost('gender') ?? [];
        $isAdults = $this->request->getPost('is_adult') ?? [];
        $isInfants = $this->request->getPost('is_infant') ?? [];

        foreach ($surnames as $index => $surname) {
            $request['passengers'][] = [
                'name' => $names[$index] ?? '',
                'surname' => $surname,
                'gender' => $genders[$index] ?? '',
                'is_adult' => isset($isAdults[$index]),
                'is_infant' => isset($isInfants[$index]),
            ];
        }

        // Process hotel information
        $hotels = [];
        $hotelIds = $this->request->getPost('hotel') ?? [];
        $roomTypeIds = $this->request->getPost('room') ?? [];
        $checkIns = $this->request->getPost('check_in') ?? [];
        $checkOuts = $this->request->getPost('check_out') ?? [];
        $nights = $this->request->getPost('nights') ?? [];
        $roomQuantities = $this->request->getPost('room_quantity') ?? [];

        foreach ($hotelIds as $index => $hotelId) {
            $hotel = $hotelModel->find($hotelId);
            $roomType = $roomTypeModel->find($roomTypeIds[$index]);
            $hotels[] = [
                'hotel_name' => $hotel['name'] ?? 'Unknown Hotel',
                'room_type' => $roomType['name'] ?? 'Unknown Room Type',
                'check_in' => $checkIns[$index] ?? '',
                'check_out' => $checkOuts[$index] ?? '',
                'nights' => $nights[$index] ?? '',
                'room_quantity' => $roomQuantities[$index] ?? '',
            ];
        }

        $pdf = $pdfGenerator->generateVoucher2($request, $hotels);
        $filename = 'voucher_' . $request['unique_id'] . '.pdf';

        return $this->response->setHeader('Content-Type', 'application/pdf')
                        ->setHeader('Content-Disposition', 'attachment; filename="'.$filename.'"')
                        ->setBody($pdf);
    }

    private function mergePDFs($pdfs)
    {
        // Implement PDF merging logic here
        // You may need to use a library like FPDI to merge PDFs
        // For now, we'll just return the first PDF
        return $pdfs[0];
    }
}