<?php namespace App\Libraries;

require_once APPPATH . 'ThirdParty/fpdf/fpdf.php';

class PdfGenerator extends \FPDF
{
    protected $headerColor;
    protected $boxColor;
    protected $textColor;

    public function __construct($orientation='P', $unit='mm', $size='A4')
    {
        parent::__construct($orientation, $unit, $size);
        $this->SetAutoPageBreak(true, 15);
        
        // Set colors
        $this->headerColor = [41, 128, 185]; // Blue
        $this->boxColor = [236, 240, 241];   // Light Gray
        $this->textColor = [44, 62, 80];     // Dark Blue
    }

    protected function drawBox($title)
    {
        $this->SetFillColor(...$this->boxColor);
        $this->Rect($this->GetX(), $this->GetY(), 190, 10, 'F');
        $this->SetFont('Arial', 'B', 12);
        $this->SetTextColor(...$this->textColor);
        $this->Cell(190, 10, $title, 0, 1, 'L');
    }
  
  	private function getFlightInfo($flight, $type)
	{
    if (empty($flight)) {
        return 'N/A (No flight data)';
    }

    $info = $flight['flight_number'] ?? 'Unknown Flight Number';
    $info .= ' - ' . ($flight['departure_city'] ?? 'Unknown Departure') . ' to ' . ($flight['arrival_city'] ?? 'Unknown Arrival');
    
    if ($type === 'arrival') {
        $info .= "\n   Departure: " . (isset($flight['departure_time']) ? date('Y-m-d H:i', strtotime($flight['departure_time'])) : 'Unknown Departure Time');
        $info .= "\n   Arrival: " . (isset($flight['arrival_time']) ? date('Y-m-d H:i', strtotime($flight['arrival_time'])) : 'Unknown Arrival Time');
    } else {
        $info .= "\n   Departure: " . (isset($flight['departure_time']) ? date('Y-m-d H:i', strtotime($flight['departure_time'])) : 'Unknown Departure Time');
        $info .= "\n   Arrival: " . (isset($flight['arrival_time']) ? date('Y-m-d H:i', strtotime($flight['arrival_time'])) : 'Unknown Arrival Time');
    }

    return $info;
	}

    public function generateVoucher($rtq, $request, $hotels)
    {
        $this->AddPage();
      	
      	if (file_exists(FCPATH . 'assets/images/logo.png')) {
            $this->Image(FCPATH . 'assets/images/logo.png', 10, 10, 30);
        }
        
        // Header
        $this->SetFillColor(...$this->headerColor);
        $this->Rect(0, 0, 210, 40, 'F');
        $this->SetFont('Arial', 'B', 24);
        $this->SetTextColor(255, 255, 255);
        $this->Cell(0, 20, 'Booking Voucher', 0, 1, 'C');
        $this->SetFont('Arial', 'B', 14);
        $this->Cell(0, 10, 'SNAP HOLIDAYS CO.,LTD.', 0, 1, 'C');
        $this->Ln(10);

        // Voucher Details
        $this->drawBox('Voucher Details');
        $this->SetFont('Arial', '', 11);
        $this->SetTextColor(...$this->textColor);
        $this->Cell(40, 7, 'RTQ ID:', 0);
        $this->Cell(0, 7, $rtq['id'], 0, 1);
        $this->Cell(40, 7, 'Request ID:', 0);
        $this->Cell(0, 7, $request['unique_id'], 0, 1);
        $this->Cell(40, 7, 'Booking Date:', 0);
        $this->Cell(0, 7, date('Y-m-d', strtotime($request['created_at'])), 0, 1);
        $this->Ln(5);

        // Flight Information
        $this->drawBox('Flight Information');
        $this->SetFont('Arial', '', 11);
        $this->Cell(40, 7, 'Arrival Flight:', 0);
        $this->Cell(0, 7, $this->getFlightInfo($request['arrival_flight'], 'arrival'), 0, 1);
        $this->Cell(40, 7, 'Departure Flight:', 0);
        $this->Cell(0, 7, $this->getFlightInfo($request['departure_flight'], 'departure'), 0, 1);
        $this->Ln(5);

        // Passenger Information
        $this->drawBox('Passenger Information');
        $this->SetFillColor(189, 195, 199); // Light gray for table header
        $this->Cell(60, 7, 'Name', 1, 0, 'C', true);
        $this->Cell(40, 7, 'Gender', 1, 0, 'C', true);
        $this->Cell(40, 7, 'Type', 1, 1, 'C', true);
        $this->SetFillColor(245, 245, 245); // Lighter gray for alternating rows
        $fill = false;
        
        if (isset($request['passengers']) && is_array($request['passengers'])) {
            foreach ($request['passengers'] as $passenger) {
                $this->Cell(60, 7, ($passenger['name'] ?? 'N/A') . ' ' . ($passenger['surname'] ?? ''), 1, 0, 'L', $fill);
                $this->Cell(40, 7, ucfirst($passenger['gender'] ?? 'N/A'), 1, 0, 'C', $fill);
                $this->Cell(40, 7, isset($passenger['is_adult']) ? ($passenger['is_adult'] ? 'Adult' : (isset($passenger['is_infant']) && $passenger['is_infant'] ? 		'Infant' : 'Child')) : 'N/A', 1, 1, 'C', $fill);
                $fill = !$fill;
            }
        } else {
            $this->Cell(140, 7, 'No passenger information available', 1, 1, 'C');
        }
        $this->Ln(5);

        // Hotel Information
        $this->drawBox('Hotel Information');
        foreach ($hotels as $hotel) {
            $this->SetFillColor(52, 152, 219); // Blue for hotel name
            $this->SetTextColor(255, 255, 255);
            $this->SetFont('Arial', 'B', 12);
            $this->Cell(190, 10, $hotel['hotel_name'], 1, 1, 'C', true);
            $this->SetFont('Arial', '', 11);
            $this->SetTextColor(...$this->textColor);
            $this->SetFillColor(189, 195, 199); // Light gray for labels
            $this->Cell(40, 7, 'Room Type', 1, 0, 'L', true);
            $this->Cell(150, 7, $hotel['room_type'], 1, 1);
            $this->Cell(40, 7, 'Check-in', 1, 0, 'L', true);
            $this->Cell(55, 7, $hotel['check_in'], 1, 0);
            $this->Cell(40, 7, 'Check-out', 1, 0, 'L', true);
            $this->Cell(55, 7, $hotel['check_out'], 1, 1);
            $this->Cell(40, 7, 'Nights', 1, 0, 'L', true);
            $this->Cell(55, 7, $hotel['nights'], 1, 0);
            $this->Cell(40, 7, 'Room Quantity', 1, 0, 'L', true);
            $this->Cell(55, 7, $hotel['room_quantity'], 1, 1);
            $this->Ln(5);
        }

        // Footer
        $this->SetY(-20);
        $this->SetFont('Arial', 'I', 8);
        $this->SetTextColor(128);
        $this->Cell(0, 10, 'This is a computer-generated document and does not require a signature.', 0, 1, 'C');
        $this->Cell(0, 10, 'Page ' . $this->PageNo() . '/{nb}', 0, 0, 'C');

        $this->AliasNbPages();
        return $this->Output('S');
    }
  
  	public function generateVoucher2($request, $hotels)
    {
        $this->AddPage();
      	
      	if (file_exists(FCPATH . 'assets/images/logo.png')) {
            $this->Image(FCPATH . 'assets/images/logo.png', 10, 10, 30);
        }
        
        // Header
        $this->SetFillColor(...$this->headerColor);
        $this->Rect(0, 0, 210, 40, 'F');
        $this->SetFont('Arial', 'B', 24);
        $this->SetTextColor(255, 255, 255);
        $this->Cell(0, 20, 'Booking Voucher', 0, 1, 'C');
        $this->SetFont('Arial', 'B', 14);
        $this->Cell(0, 10, 'SNAP HOLIDAYS CO.,LTD.', 0, 1, 'C');
        $this->Ln(10);

        // Voucher Details
        $this->drawBox('Voucher Details');
        $this->SetFont('Arial', '', 11);
        $this->SetTextColor(...$this->textColor);
    
        $this->Cell(40, 7, 'Request ID:', 0);
        $this->Cell(0, 7, $request['unique_id'], 0, 1);
        $this->Cell(40, 7, 'Booking Date:', 0);
        $this->Cell(0, 7, date('Y-m-d', strtotime($request['created_at'])), 0, 1);
        $this->Ln(5);

        // Flight Information
        $this->drawBox('Flight Information');
        $this->SetFont('Arial', '', 11);
        $this->Cell(40, 7, 'Arrival Flight:', 0);
        $this->Cell(0, 7, $this->getFlightInfo($request['arrival_flight'], 'arrival'), 0, 1);
        $this->Cell(40, 7, 'Departure Flight:', 0);
        $this->Cell(0, 7, $this->getFlightInfo($request['departure_flight'], 'departure'), 0, 1);
        $this->Ln(5);

        // Passenger Information
        $this->drawBox('Passenger Information');
        $this->SetFillColor(189, 195, 199); // Light gray for table header
        $this->Cell(60, 7, 'Name', 1, 0, 'C', true);
        $this->Cell(40, 7, 'Gender', 1, 0, 'C', true);
        $this->Cell(40, 7, 'Type', 1, 1, 'C', true);
        $this->SetFillColor(245, 245, 245); // Lighter gray for alternating rows
        $fill = false;
        
        if (isset($request['passengers']) && is_array($request['passengers'])) {
            foreach ($request['passengers'] as $passenger) {
                $this->Cell(60, 7, ($passenger['name'] ?? 'N/A') . ' ' . ($passenger['surname'] ?? ''), 1, 0, 'L', $fill);
                $this->Cell(40, 7, ucfirst($passenger['gender'] ?? 'N/A'), 1, 0, 'C', $fill);
                $this->Cell(40, 7, isset($passenger['is_adult']) ? ($passenger['is_adult'] ? 'Adult' : (isset($passenger['is_infant']) && $passenger['is_infant'] ? 		'Infant' : 'Child')) : 'N/A', 1, 1, 'C', $fill);
                $fill = !$fill;
            }
        } else {
            $this->Cell(140, 7, 'No passenger information available', 1, 1, 'C');
        }
        $this->Ln(5);

        // Hotel Information
        $this->drawBox('Hotel Information');
        foreach ($hotels as $hotel) {
            $this->SetFillColor(52, 152, 219); // Blue for hotel name
            $this->SetTextColor(255, 255, 255);
            $this->SetFont('Arial', 'B', 12);
            $this->Cell(190, 10, $hotel['hotel_name'], 1, 1, 'C', true);
            $this->SetFont('Arial', '', 11);
            $this->SetTextColor(...$this->textColor);
            $this->SetFillColor(189, 195, 199); // Light gray for labels
            $this->Cell(40, 7, 'Room Type', 1, 0, 'L', true);
            $this->Cell(150, 7, $hotel['room_type'], 1, 1);
            $this->Cell(40, 7, 'Check-in', 1, 0, 'L', true);
            $this->Cell(55, 7, $hotel['check_in'], 1, 0);
            $this->Cell(40, 7, 'Check-out', 1, 0, 'L', true);
            $this->Cell(55, 7, $hotel['check_out'], 1, 1);
            $this->Cell(40, 7, 'Nights', 1, 0, 'L', true);
            $this->Cell(55, 7, $hotel['nights'], 1, 0);
            $this->Cell(40, 7, 'Room Quantity', 1, 0, 'L', true);
            $this->Cell(55, 7, $hotel['room_quantity'], 1, 1);
            $this->Ln(5);
        }

        // Footer
        $this->SetY(-20);
        $this->SetFont('Arial', 'I', 8);
        $this->SetTextColor(128);
        $this->Cell(0, 10, 'This is a computer-generated document and does not require a signature.', 0, 1, 'C');
        $this->Cell(0, 10, 'Page ' . $this->PageNo() . '/{nb}', 0, 0, 'C');

        $this->AliasNbPages();
        return $this->Output('S');
    }
  
  
  	public function generateHotelVoucher($rtq, $request, $hotel)
    {
        $this->AddPage();
        
        // Header
        $this->SetFillColor(...$this->headerColor);
        $this->Rect(0, 0, 210, 40, 'F');
        $this->SetFont('Arial', 'B', 24);
        $this->SetTextColor(255, 255, 255);
        $this->Cell(0, 20, 'Booking Voucher', 0, 1, 'C');
        $this->SetFont('Arial', 'B', 14);
        $this->Cell(0, 10, 'SNAP HOLIDAYS CO.,LTD.', 0, 1, 'C');
        $this->Ln(10);

        // Voucher Details
        $this->drawBox('Voucher Details');
        $this->SetFont('Arial', '', 11);
        $this->SetTextColor(...$this->textColor);
        $this->Cell(40, 7, 'RTQ ID:', 0);
        $this->Cell(0, 7, $rtq['id'], 0, 1);
        $this->Cell(40, 7, 'Request ID:', 0);
        $this->Cell(0, 7, $request['unique_id'], 0, 1);
        $this->Cell(40, 7, 'Booking Date:', 0);
        $this->Cell(0, 7, date('Y-m-d', strtotime($request['created_at'])), 0, 1);
        $this->Ln(5);

        // Flight Information
        $this->drawBox('Flight Information');
        $this->SetFont('Arial', '', 11);
        $this->Cell(40, 7, 'Arrival Flight:', 0);
        $this->Cell(0, 7, $this->getFlightInfo($request['arrival_flight'], 'arrival'), 0, 1);
        $this->Cell(40, 7, 'Departure Flight:', 0);
        $this->Cell(0, 7, $this->getFlightInfo($request['departure_flight'], 'departure'), 0, 1);
        $this->Ln(5);

        // Hotel Information
        $this->drawBox('Hotel Information');
        $this->SetFillColor(52, 152, 219); // Blue for hotel name
        $this->SetTextColor(255, 255, 255);
        $this->SetFont('Arial', 'B', 12);
        $this->Cell(190, 10, $hotel['hotel_name'], 1, 1, 'C', true);
        $this->SetFont('Arial', '', 11);
        $this->SetTextColor(...$this->textColor);
        $this->SetFillColor(189, 195, 199); // Light gray for labels
        $this->Cell(40, 7, 'Room Type', 1, 0, 'L', true);
        $this->Cell(150, 7, $hotel['room_type'], 1, 1);
        $this->Cell(40, 7, 'Check-in', 1, 0, 'L', true);
        $this->Cell(55, 7, $hotel['check_in'], 1, 0);
        $this->Cell(40, 7, 'Check-out', 1, 0, 'L', true);
        $this->Cell(55, 7, $hotel['check_out'], 1, 1);
        $this->Cell(40, 7, 'Nights', 1, 0, 'L', true);
        $this->Cell(55, 7, $hotel['nights'], 1, 0);
        $this->Cell(40, 7, 'Room Quantity', 1, 0, 'L', true);
        $this->Cell(55, 7, $hotel['room_quantity'], 1, 1);
        $this->Ln(5);

        // Passenger Information
        $this->drawBox('Passenger Information');
        $this->SetFillColor(189, 195, 199); // Light gray for table header
        $this->Cell(60, 7, 'Name', 1, 0, 'C', true);
        $this->Cell(40, 7, 'Gender', 1, 0, 'C', true);
        $this->Cell(40, 7, 'Type', 1, 1, 'C', true);
        $this->SetFillColor(245, 245, 245); // Lighter gray for alternating rows
        $fill = false;
        foreach ($request['passengers'] as $passenger) {
            $this->Cell(60, 7, $passenger['name'] . ' ' . $passenger['surname'], 1, 0, 'L', $fill);
            $this->Cell(40, 7, ucfirst($passenger['gender']), 1, 0, 'C', $fill);
            $this->Cell(40, 7, $passenger['is_adult'] ? 'Adult' : ($passenger['is_infant'] ? 'Infant' : 'Child'), 1, 1, 'C', $fill);
            $fill = !$fill;
        }

        // Footer
        $this->SetY(-20);
        $this->SetFont('Arial', 'I', 8);
        $this->SetTextColor(128);
        $this->Cell(0, 10, 'This is a computer-generated document and does not require a signature.', 0, 1, 'C');
        $this->Cell(0, 10, 'Page ' . $this->PageNo() . '/{nb}', 0, 0, 'C');

        $this->AliasNbPages();
        return $this->Output('S');
    }
}