<?php

namespace App\Models;

use CodeIgniter\Model;

class HotelModel extends Model
{
    protected $table = 'hotels';
    protected $primaryKey = 'id';
    protected $allowedFields = ['name', 'city_id', 'email', 'agent_name', 'is_active'];
    protected $useTimestamps = true;
    protected $dateFormat = 'datetime';
    protected $createdField = 'created_at';
    protected $updatedField = 'updated_at';

    protected $validationRules = [
        'name' => 'required|min_length[3]|max_length[255]',
        'city_id' => 'required|numeric',
        'email' => 'required|valid_email',
        'agent_name' => 'required|min_length[3]|max_length[255]',
        'is_active' => 'in_list[0,1]',
    ];

    protected $validationMessages = [
        'name' => [
            'required' => 'Hotel name is required',
            'min_length' => 'Hotel name must be at least 3 characters long',
            'max_length' => 'Hotel name cannot exceed 255 characters',
        ],
        'city_id' => [
            'required' => 'City is required',
            'numeric' => 'Invalid city selected',
        ],
        'email' => [
            'required' => 'Email is required',
            'valid_email' => 'Please enter a valid email address',
        ],
        'agent_name' => [
            'required' => 'Agent name is required',
            'min_length' => 'Agent name must be at least 3 characters long',
            'max_length' => 'Agent name cannot exceed 255 characters',
        ],
        'is_active' => [
            'in_list' => 'Invalid active status',
        ],
    ];

    protected $skipValidation = false;
}