<?= $this->extend('layout/dashboard') ?>

<?= $this->section('content') ?>
<div class="card">
    <div class="card-header">
        <h3 class="card-title">Flight Management</h3>
    </div>
    <div class="card-body">
        <button type="button" class="btn btn-primary mb-3" data-toggle="modal" data-target="#addFlightModal">
            Add New Flight
        </button>
        <table class="table table-bordered table-striped" id="flightTable">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Flight Number</th>
                    <th>Departure City</th>
                    <th>Arrival City</th>
                    <th>Departure Time</th>
                    <th>Arrival Time</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($flights as $flight): ?>
                <tr>
                    <td><?= $flight['id'] ?></td>
                    <td><?= esc($flight['flight_number']) ?></td>
                    <td><?= esc($flight['departure_city']) ?></td>
                    <td><?= esc($flight['arrival_city']) ?></td>
                    <td><?= $flight['departure_time'] ?></td>
                    <td><?= $flight['arrival_time'] ?></td>
                    <td>
                        <button class="btn btn-danger btn-sm delete-flight" data-id="<?= $flight['id'] ?>">Delete</button>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- Add Flight Modal -->
<div class="modal fade" id="addFlightModal" tabindex="-1" role="dialog" aria-labelledby="addFlightModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="addFlightModalLabel">Add New Flight</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form id="addFlightForm">
                    <div class="form-group">
                        <label for="flight_number">Flight Number</label>
                        <input type="text" class="form-control" id="flight_number" name="flight_number" required>
                    </div>
                    <div class="form-group">
                        <label for="departure_city">Departure City</label>
                        <input type="text" class="form-control" id="departure_city" name="departure_city" required>
                    </div>
                    <div class="form-group">
                        <label for="arrival_city">Arrival City</label>
                        <input type="text" class="form-control" id="arrival_city" name="arrival_city" required>
                    </div>
                    <div class="form-group">
                        <label for="departure_time">Departure Time</label>
                        <input type="datetime-local" class="form-control" id="departure_time" name="departure_time" required>
                    </div>
                    <div class="form-group">
                        <label for="arrival_time">Arrival Time</label>
                        <input type="datetime-local" class="form-control" id="arrival_time" name="arrival_time" required>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                <button type="button" class="btn btn-primary" id="submitFlight">Add Flight</button>
            </div>
        </div>
    </div>
</div>

<script>
$(document).ready(function() {
    $('#flightTable').DataTable();

    $('#submitFlight').click(function() {
        var formData = $('#addFlightForm').serialize();
        
        // Convert datetime-local to ISO format
        var departureMoment = moment($('#departure_time').val(), 'YYYY-MM-DDTHH:mm');
        var arrivalMoment = moment($('#arrival_time').val(), 'YYYY-MM-DDTHH:mm');
        
        formData += '&departure_time=' + departureMoment.format('YYYY-MM-DD HH:mm:ss');
        formData += '&arrival_time=' + arrivalMoment.format('YYYY-MM-DD HH:mm:ss');

        $.ajax({
            url: '<?= base_url('flight-management/add') ?>',
            type: 'POST',
            data: formData,
            dataType: 'json',
            success: function(response) {
                if (response.success) {
                    alert(response.message);
                    location.reload();
                } else {
                    var errorMessage = 'Error: ';
                    if (typeof response.message === 'object') {
                        for (var key in response.message) {
                            errorMessage += response.message[key] + '\n';
                        }
                    } else {
                        errorMessage += response.message || 'Unknown error occurred';
                    }
                    alert(errorMessage);
                }
            },
            error: function(xhr, status, error) {
                console.error(xhr.responseText);
                alert('An error occurred. Please try again.');
            }
        });
    });

    $('.delete-flight').click(function() {
        if (confirm('Are you sure you want to delete this flight?')) {
            var flightId = $(this).data('id');
            $.ajax({
                url: '<?= base_url('flight-management/delete') ?>/' + flightId,
                type: 'POST',
                dataType: 'json',
                success: function(response) {
                    if (response.success) {
                        alert(response.message);
                        location.reload();
                    } else {
                        alert('Error: ' + response.message);
                    }
                },
                error: function(xhr, status, error) {
                    console.error(xhr.responseText);
                    alert('An error occurred. Please try again.');
                }
            });
        }
    });
});
</script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.29.1/moment.min.js"></script>

<?= $this->endSection() ?>