<?= $this->extend('layout/dashboard') ?>

<?= $this->section('content') ?>
<div class="card">
    <div class="card-header">
        <h3 class="card-title">All Requests</h3>
        <div class="card-tools">
            <form action="<?= base_url('requests/search') ?>" method="get">
                <div class="input-group input-group-sm" style="width: 150px;">
                    <input type="text" name="search" class="form-control float-right" placeholder="Search">
                    <div class="input-group-append">
                        <button type="submit" class="btn btn-default">
                            <i class="fas fa-search"></i>
                        </button>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <div class="card-body table-responsive p-0">
        <table class="table table-hover text-nowrap table-bordered table-striped" id="requestTable">
            <thead>
                <tr>
                    <th>Request ID</th>
                    <th>Submission Date</th>
                    <th>Submitted By</th>
                    <th>Status</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($requests as $request): ?>
                <tr>
                    <td><?= $request['unique_id'] ?></td>
                    <td><?= date('Y-m-d H:i', strtotime($request['created_at'])) ?></td>
                    <td><?= esc($request['username']) ?></td>
                    <td>
                        <?php
                        $statusClass = [
                            'new' => 'badge bg-primary',
                            'staff reply' => 'badge bg-info',
                            'waiting for confirmation' => 'badge bg-warning',
                            'declined' => 'badge bg-danger',
                            'confirmed' => 'badge bg-success'
                        ];
                        $class = isset($statusClass[$request['status']]) ? $statusClass[$request['status']] : 'badge bg-secondary';
                        ?>
                        <span class="<?= $class ?>"><?= ucfirst($request['status']) ?></span>
                    </td>
                    <td>
                        <a href="<?= base_url('requests/view/' . $request['id']) ?>" class="btn btn-sm btn-info">View</a>
                        <a href="<?= base_url('requests/edit/' . $request['id']) ?>" class="btn btn-sm btn-warning">Edit</a>
                        <a href="<?= base_url('requests/delete/' . $request['id']) ?>" class="btn btn-sm btn-danger" onclick="return confirm('Are you sure you want to delete this request?')">Delete</a>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>
<script>
document.addEventListener('DOMContentLoaded', function() {
  $('#requestTable').DataTable();
});
</script>
<?= $this->endSection() ?>