<?= $this->extend('layout/dashboard') ?>

<?= $this->section('content') ?>

<div class="container-fluid">
    <div class="row mb-4">
        <div class="col-md-12">
            <div class="card">
                <div class="card-header bg-primary text-white">
                    <h3 class="card-title mb-0">RTQ Details: <?= isset($rtq['id']) ? 'RTQ-' . str_pad($rtq['id'], 5, '0', STR_PAD_LEFT) : 'N/A' ?></h3>
                </div>
                <div class="card-body">
                    <?php if (isset($rtq) && isset($request)): ?>
                        <!-- RTQ Information -->
                        <div class="row">
                            <div class="col-md-6">
                                <h4 class="text-primary">RTQ Information</h4>
                                <table class="table table-bordered">
                                    <tr>
                                        <th>Status</th>
                                        <td><span class="badge bg-<?= ($rtq['status'] ?? '') == 'pending' ? 'warning' : (($rtq['status'] ?? '') == 'confirmed' ? 'success' : 'danger') ?>"><?= ucfirst(esc($rtq['status'] ?? 'N/A')) ?></span></td>
                                    </tr>
                                    <tr>
                                        <th>Created At</th>
                                        <td><?= esc($rtq['created_at'] ?? 'N/A') ?></td>
                                    </tr>
                                    <tr>
                                        <th>Notes</th>
                                        <td><?= esc($rtq['notes'] ?? 'N/A') ?></td>
                                    </tr>
                                </table>
                            </div>
                            <div class="col-md-6">
                                <h4 class="text-primary">Request Information</h4>
                                <table class="table table-bordered">
                                    <tr>
                                        <th>Request ID</th>
                                        <td><?= esc($request['unique_id'] ?? 'N/A') ?></td>
                                    </tr>
                                    <tr>
                                        <th>Status</th>
                                        <td><span class="badge bg-info"><?= ucfirst(esc($request['status'] ?? 'N/A')) ?></span></td>
                                    </tr>
                                    <tr>
                                        <th>Created At</th>
                                        <td><?= esc($request['created_at'] ?? 'N/A') ?></td>
                                    </tr>
                                </table>
                            </div>
                        </div>

                        <!-- Hotel Information -->
                        <h4 class="text-primary mt-4">Hotel Information</h4>
                        <?php if (isset($rtq['hotels']) && is_array($rtq['hotels']) && !empty($rtq['hotels'])): ?>
                            <?php foreach ($rtq['hotels'] as $hotel): ?>
                                <div class="card mb-3">
                                    <div class="card-body">
                                        <h5 class="card-title"><?= esc($hotel['hotel_name'] ?? 'N/A') ?></h5>
                                        <p><strong class="badge bg-warning">Status:</strong> <?= ucfirst($hotel['rtq_status'] ?? 'N/A') ?></p>
                                        <p><strong>Email:</strong> <?= esc($hotel['hotel_email'] ?? 'N/A') ?></p>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <p><strong>Room Type:</strong> <?= esc($hotel['room_type'] ?? 'N/A') ?></p>
                                                <p><strong>Check-in:</strong> <?= esc($hotel['check_in'] ?? 'N/A') ?></p>
                                                <p><strong>Check-out:</strong> <?= esc($hotel['check_out'] ?? 'N/A') ?></p>
                                            </div>
                                            <div class="col-md-6">
                                                <p><strong>Nights:</strong> <?= esc($hotel['nights'] ?? 'N/A') ?></p>
                                                <p><strong>Room Quantity:</strong> <?= esc($hotel['room_quantity'] ?? 'N/A') ?></p>
                                                <p><strong>Extra Bed:</strong> <?= isset($hotel['extra_bed']) && $hotel['extra_bed'] ? 'Yes' : 'No' ?></p>
                                                <p><strong>Status:</strong>
                                                    <select class="form-control hotel-status" data-rtq-id="<?= $rtq['id'] ?>" data-hotel-id="<?= $hotel['hotel_id'] ?>">
                                                        <option value="pending" <?= ($hotel['rtq_status'] ?? '') == 'pending' ? 'selected' : '' ?>>Pending</option>
                                                        <option value="sent to hotel" <?= ($hotel['rtq_status'] ?? '') == 'sent to hotel' ? 'selected' : '' ?>>Sent to Hotel</option>
                                                        <option value="confirmed" <?= ($hotel['rtq_status'] ?? '') == 'confirmed' ? 'selected' : '' ?>>Confirmed</option>
                                                        <option value="need change" <?= ($hotel['rtq_status'] ?? '') == 'need change' ? 'selected' : '' ?>>Need Change</option>
                                                    </select>
                                                </p>
                                            </div>
                                        </div>
                                        <?php if (($hotel['rtq_status'] ?? '') != 'sent to hotel' && !empty($hotel['hotel_email'])): ?>
                                            <button class="btn btn-primary send-to-hotel" data-rtq-id="<?= $rtq['id'] ?>" data-hotel-id="<?= $hotel['hotel_id'] ?>">Send to Hotel</button>
                                        <?php elseif (empty($hotel['hotel_email'])): ?>
                                            <p class="text-danger">Cannot send voucher: Hotel email is missing</p>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <p class="alert alert-info">No hotel information available.</p>
                        <?php endif; ?>

                        <!-- Passenger Information -->
                        <h4 class="text-primary mt-4">Passenger Information</h4>
                        <?php if (isset($request['passengers']) && is_array($request['passengers']) && !empty($request['passengers'])): ?>
                            <div class="table-responsive">
                                <table class="table table-bordered table-striped">
                                    <thead>
                                        <tr>
                                            <th>Name</th>
                                            <th>Surname</th>
                                            <th>Gender</th>
                                            <th>Type</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($request['passengers'] as $passenger): ?>
                                            <tr>
                                                <td><?= esc($passenger['name'] ?? 'N/A') ?></td>
                                                <td><?= esc($passenger['surname'] ?? 'N/A') ?></td>
                                                <td><?= ucfirst(esc($passenger['gender'] ?? 'N/A')) ?></td>
                                                <td>
                                                    <?php
                                                    if (isset($passenger['is_adult']) && $passenger['is_adult']) {
                                                        echo 'Adult';
                                                    } elseif (isset($passenger['is_infant']) && $passenger['is_infant']) {
                                                        echo 'Infant';
                                                    } else {
                                                        echo 'Child';
                                                    }
                                                    ?>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php else: ?>
                            <p class="alert alert-info">No passenger information available.</p>
                        <?php endif; ?>

                        <!-- Actions -->
                        <div class="mt-4">
                            <h4 class="text-primary">Actions</h4>
                            <?php if (empty($rtq['voucher_path'])): ?>
                                <a href="<?= base_url('rtq/generateVoucher/' . $rtq['id']) ?>" class="btn btn-success">Generate Voucher</a>
                            <?php else: ?>
                                <a href="<?= base_url('rtq/downloadVoucher/' . $rtq['id']) ?>" class="btn btn-primary">Download Voucher</a>
                            <?php endif; ?>
                            <button id="update-rtq-status" class="btn btn-primary">Update RTQ Status</button>
                            <button id="send-to-hotel" class="btn btn-success">Send to Hotel</button>
                            <button id="cancel-rtq" class="btn btn-danger">Cancel RTQ</button>
                        </div>

                    <?php else: ?>
                        <p class="alert alert-danger">Error: RTQ or Request data is missing.</p>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Notes Section -->
<div class="row mt-4">
    <div class="col-md-6">
        <div class="card">
            <div class="card-header">
                <h5>Notes</h5>
            </div>
            <div class="card-body">
                <?php if (isset($notes) && is_array($notes)): ?>
                    <?php foreach ($notes as $note): ?>
                        <div class="mb-2">
                            <strong><?= esc($note['created_at'] ?? 'N/A') ?>:</strong> <?= esc($note['note'] ?? 'N/A') ?>
                        </div>
                    <?php endforeach; ?>
                <?php else: ?>
                    <p>No notes available.</p>
                <?php endif; ?>
                <form action="<?= base_url('rtq/addNote') ?>" method="post">
                    <input type="hidden" name="rtq_id" value="<?= $rtq['id'] ?? '' ?>">
                    <div class="form-group">
                        <textarea name="note" class="form-control" rows="3" required></textarea>
                    </div>
                    <button type="submit" class="btn btn-primary">Add Note</button>
                </form>
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="card">
            <div class="card-header">
                <h5>RTQ Log</h5>
            </div>
            <div class="card-body">
                <?php if (isset($logs) && is_array($logs)): ?>
                    <?php foreach ($logs as $log): ?>
                        <div class="mb-2">
                            <strong><?= esc($log['created_at'] ?? 'N/A') ?>:</strong> <?= esc($log['username'] ?? 'Unknown') ?> <?= esc($log['activity'] ?? 'N/A') ?>
                        </div>
                    <?php endforeach; ?>
                <?php else: ?>
                    <p>No logs available.</p>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<script>
$(document).ready(function() {
    $('.hotel-status').change(function() {
        var rtqId = $(this).data('rtq-id');
        var hotelId = $(this).data('hotel-id');
        var status = $(this).val();

        $.post('<?= base_url('rtq/updateHotelStatus') ?>', {
            rtq_id: rtqId,
            hotel_id: hotelId,
            status: status
        }, function(response) {
            if (response.success) {
                alert('Hotel status updated successfully');
            } else {
                alert('Failed to update hotel status');
            }
        });
    });

    $('.send-to-hotel').click(function() {
        var rtqId = $(this).data('rtq-id');
        var hotelId = $(this).data('hotel-id');
        
        $.ajax({
            url: '<?= base_url('rtq/sendToHotel') ?>',
            type: 'POST',
            data: {
                rtq_id: rtqId,
                hotel_id: hotelId
            },
            dataType: 'json',
            success: function(response) {
                if (response.success) {
                    alert(response.message);
                    location.reload();
                } else {
                    alert('Failed to send voucher: ' + response.message);
                }
            },
            error: function() {
                alert('An error occurred while sending the voucher.');
            }
        });
    });
});
</script>

<?= $this->endSection() ?>