<?= $this->extend('layout/dashboard') ?>

<?= $this->section('content') ?>

<div class="container">
    <h2>User Management</h2>
    <a href="<?= base_url('user-management/add') ?>" class="btn btn-primary mb-3">Add New User</a>
    <table class="table table-striped">
        <thead>
            <tr>
                <th>ID</th>
                <th>Username</th>
                <th>Email</th>
                <th>Role</th>
                <th>Status</th>
                <th>Actions</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($users as $user): ?>
            <tr>
                <td><?= $user['id'] ?></td>
                <td><?= esc($user['username']) ?></td>
                <td><?= esc($user['email']) ?></td>
                <td><?= esc($user['role']) ?></td>
                <td>
                    <button class="btn btn-sm <?= $user['is_active'] ? 'btn-success' : 'btn-danger' ?> toggle-status" data-user-id="<?= $user['id'] ?>">
                        <?= $user['is_active'] ? 'Active' : 'Inactive' ?>
                    </button>
                </td>
                <td>
                    <a href="<?= base_url('user-management/edit/' . $user['id']) ?>" class="btn btn-sm btn-warning">Edit</a>
                    <button class="btn btn-sm btn-danger delete-user" data-user-id="<?= $user['id'] ?>">Delete</button>
                    <a href="<?= base_url('user-management/user-requests/' . $user['id']) ?>" class="btn btn-sm btn-info">User Requests</a>
                </td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<script>
$(document).ready(function() {
    $('.toggle-status').click(function() {
        var userId = $(this).data('user-id');
        var button = $(this);

        $.ajax({
            url: '<?= base_url('user-management/toggle-user-status') ?>/' + userId,
            type: 'POST',
            dataType: 'json',
            success: function(response) {
                if (response.success) {
                    if (response.newStatus) {
                        button.removeClass('btn-danger').addClass('btn-success').text('Active');
                    } else {
                        button.removeClass('btn-success').addClass('btn-danger').text('Inactive');
                    }
                } else {
                    alert(response.message);
                }
            },
            error: function() {
                alert('An error occurred while updating user status.');
            }
        });
    });
  
  	$('.delete-user').click(function() {
        var userId = $(this).data('user-id');
        if (confirm('Are you sure you want to delete this user?')) {
            $.ajax({
                url: '<?= base_url('user-management/delete') ?>/' + userId,
                type: 'POST',
                dataType: 'json',
                success: function(response) {
                    if (response.success) {
                        alert(response.message);
                        location.reload();
                    } else {
                        alert(response.message);
                    }
                },
                error: function() {
                    alert('An error occurred while deleting the user.');
                }
            });
        }
    });
});
</script>

<?= $this->endSection() ?>